#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-class-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-class-plugin-2.3.0.0-3osw1pPjwLZBI7WFwja7y8
key:                  hls-class-plugin-2.3.0.0-3osw1pPjwLZBI7WFwja7y8
license:              Apache-2.0
maintainer:           jjc9310@gmail.com
author:               Junyoung Clare Jang
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:
    Class/instance management plugin for Haskell Language Server

description:
    Class/instance management plugin for Haskell Language Server.
    For usage, please see README of HLS on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  053e1d3d535497aca6fe03b68e61c656
exposed:              True
exposed-modules:      Ide.Plugin.Class
hidden-modules:
    Ide.Plugin.Class.CodeAction Ide.Plugin.Class.CodeLens
    Ide.Plugin.Class.ExactPrint Ide.Plugin.Class.Types
    Ide.Plugin.Class.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-class-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-class-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-class-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-class-plugin
hs-libraries:         HShls-class-plugin-2.3.0.0-3osw1pPjwLZBI7WFwja7y8
depends:
    aeson-2.2.2.0-3wIqYzgVLxh1lGuh6CHfOQ base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 extra-1.7.16-KrpFpNhh5BQELeEbiAlFs2 ghc-9.6.6
    ghc-boot-th-9.6.6 ghc-exactprint-1.7.1.0-EzYZZQxU9PGGhNDkq7zQqY
    ghcide-2.3.0.0-FhAbwsYEp6gAQgAB6C5VjW
    hls-graph-2.3.0.0-KobRHxNrtwkHIxNFmJfkC4
    hls-plugin-api-2.3.0.0-HoObs2qHfNKC106GqibI71
    lens-5.3.4-GdOistvs0Ub2JwuPi3uyv5
    lsp-2.2.0.0-KGqb1yHTwPvBLMtVxTPYxl mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-class-plugin/html/hls-class-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-class-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

